/**
 * Module dependencies
 */

const path = require('path');
const execSync = require('child_process').execSync;
const styleSheetsExtracted = require('./style-sheets-extracted');
const fs = require('fs');

/**
 * Load configuration
 */

const projectDirectory = path.resolve(`${__dirname}/../`);

  /**
   * Build client files with Webpack
   */

try {
  console.info('-- bundling js and css...');
  const out = execSync(
    './node_modules/.bin/webpack -p --config webpack.build.config.js',
    {
      cwd: projectDirectory,
      env: { NODE_ENV: 'production', PATH: process.env.PATH },
      uid: process.env.UID
    }
  );
  const parsedOut = out.toString().split('ERROR');
  if (parsedOut.length > 1) {
    parsedOut.shift();
    console.error(`ERROR ${parsedOut.join('ERROR')}`);
    process.exit(1);
  } else {
    console.info('-- finished bundling client files');
  }
} catch (err) {
  console.error(err);
  process.exit(1);
}

/**
 * Build server files with Babel
 */

try {
  const workingDirectory = path.resolve(`${projectDirectory}/src`);
  const outBabel = execSync(
    'babel ./ --out-dir ../lib',
    {
      cwd: workingDirectory,
      env: { NODE_ENV: 'production', PATH: process.env.PATH },
      uid: process.env.UID
    }
  );
  const parsedOutBabel = outBabel.toString().split('ERROR');
  if (parsedOutBabel.length > 1) {
    parsedOutBabel.shift();
    console.error(`ERROR ${parsedOutBabel.join('ERROR')}`);
    process.exit(1);
  } else {
    console.info('-- finished building lib');
    styleSheetsExtracted.forEach(styleSheetName => {
      const pathJsFile = `${projectDirectory}/lib/${styleSheetName}.js`;
      if (fs.existsSync(pathJsFile)) {
        fs.renameSync(pathJsFile, `${projectDirectory}/lib/${styleSheetName}/webpack-build.js`);
      }
    });
  }
} catch (err) {
  console.error(err);
  process.exit(1);
}
