/* eslint-disable jsx-a11y/label-has-for, jsx-a11y/no-static-element-interactions */
import React from 'react';
import PropTypes from 'prop-types';
import omit from 'lodash/omit';
import classNames from 'classnames';
import FieldControl from '../FieldControl/index';

import './checkbox.scss';

function getInputProps(props) {
  const { input, ...resultProps } = props;
  return { ...resultProps, ...input };
}

const propTypes = {
  optionValue: PropTypes.oneOfType([
    PropTypes.string,
    PropTypes.number,
    PropTypes.bool,
    PropTypes.array,
    PropTypes.object
  ]),
  children: PropTypes.node,
  input: PropTypes.object,
  variant: PropTypes.oneOf(['toggle-switch'])
};

const defaultProps = {
  input: null,
  children: null,
  variant: undefined,
  optionValue: true
};

class CheckBox extends React.Component {
  onChange = event => {
    const { onChange, optionValue } = getInputProps(this.props);
    const { target: { checked } } = event;
    if (typeof onChange === 'function') {
      onChange(checked ? optionValue : false, optionValue);
    }
  };

  onBlur = event => {
    const { onBlur, optionValue } = getInputProps(this.props);
    const { target: { checked } } = event;
    if (typeof onBlur === 'function') {
      onBlur(checked ? optionValue : false, optionValue);
    }
  }
  handleOnClick = () => {
    this.input.click();
  }

  render() {
    const {
      children,
      variant,
      ...props
    } = this.props;

    return (
      <FieldControl {...props}>
        {restProps => {
          const resultProps = omit(getInputProps(restProps), ['id', 'type', 'checked',
            'onChange', 'optionValue', 'onBlur']);
          return (
            <div styleName={classNames('base', variant)}>
              <input
                ref={input => { this.input = input; }}
                type="checkbox"
                onChange={this.onChange}
                onBlur={this.onBlur}
                checked={resultProps.value !== false && resultProps.value !== '' && resultProps.value !== undefined}
                {...resultProps}
              />
              <label onClick={this.handleOnClick}>
                {children}
              </label>
            </div>
          );
        }}
      </FieldControl>
    );
  }
}

CheckBox.propTypes = propTypes;
CheckBox.defaultProps = defaultProps;
export default CheckBox;
