import React, { Component } from 'react';
import PropTypes from 'prop-types';
import TextIcon from '../../TextIcon';
import Button from '../../Button';
import Icon from '../../Icon';
import Modal from '../../Modal';
import TextInput from '../../TextInput';
import Hint from '../../FieldControl/Hint';
import Progress from '../../Progress';
import Spinner from '../../Spinner';

import './list-file.scss';

const { Header, Body, Footer } = Modal;

const propTypes = {
  value: PropTypes.PropTypes.arrayOf(
    PropTypes.shape({
      name: PropTypes.string,
      preview: PropTypes.string,
      loading: PropTypes.bool
    })
  ).isRequired,
  handleDelete: PropTypes.func,
  handleEdit: PropTypes.func,
  customModalEdit: PropTypes.bool,
  children: PropTypes.node,
  allowDelete: PropTypes.bool,
  allowEdit: PropTypes.bool
};

const defaultProps = {
  handleDelete: undefined,
  handleEdit: undefined,
  customModalEdit: false,
  children: undefined,
  allowDelete: true,
  allowEdit: true
};

class ListFile extends Component {
  state = {
    fileEditRow: false,
    fileName: ''
  };

  handlerDelete = (file, row) => () => {
    const { handleDelete } = this.props;
    if (handleDelete) {
      handleDelete(file, row);
    }
  };

  handlerEdit = (file, row) => () => {
    const { handleEdit, customModalEdit } = this.props;
    if (!handleEdit) return;
    if (customModalEdit) {
      handleEdit(file, row);
    } else {
      this.setState({
        fileEditRow: row,
        fileName: file.name
      });
    }
  };

  handleFileNameChange = ({ target = {} } = {}) =>
    this.setState({ fileName: target.value });
  handleCloseModal = () => this.setState({ fileEditRow: false, fileName: '' });
  handleValidName = () => {
    const { value, handleEdit } = this.props;
    const { fileEditRow, fileName } = this.state;
    if (handleEdit) {
      const file = value.find((item, row) => fileEditRow === row);
      handleEdit({ ...file, name: fileName }, fileEditRow);
    }
    this.setState({ fileEditRow: false, fileName: '' });
  };

  render() {
    const { value, allowDelete, allowEdit, children } = this.props;
    const { fileEditRow, fileName } = this.state;
    return (
      <div styleName="base">
        {value.map((file, row) => {
          const { status, key, preview, name, progress, progressBar } = file;
          if (status === 'pending') {
            return progressBar ? (
              <Progress styleName="progress-bar" value={progress} />
            ) : (
              <Spinner />
            );
          }
          return (
            <div styleName="content" key={key || preview}>
              <TextIcon name="doc" size="sm">
                {name}
                {allowDelete && (
                  <Button
                    onClick={this.handlerDelete(file, row)}
                    type="button"
                    styleName="button-trash"
                    variant="icon"
                    size="sm"
                  >
                    <Icon name="trash" size="xs" />
                  </Button>
                )}
                {allowEdit && (
                  <Button
                    onClick={this.handlerEdit(file, row)}
                    type="button"
                    styleName="button-trash"
                    variant="icon"
                    size="sm"
                  >
                    <Icon name="edit" size="xs" />
                  </Button>
                )}
              </TextIcon>
              {status === 'error' && (
                <Hint variant="danger">
                  Something went wrong, please try again.
                </Hint>
              )}
            </div>
          );
        })}
        {children}
        {fileEditRow !== false && (
          <Modal isOpen size="sm">
            <Header onClose={this.handleCloseModal}>Edit file name</Header>
            <Body>
              <TextInput
                value={fileName}
                onChange={this.handleFileNameChange}
              />
            </Body>
            <Footer>
              <Button type="button" onClick={this.handleValidName}>
                Ok
              </Button>
              <Button
                type="button"
                variant="cancel"
                onClick={this.handleCloseModal}
              >
                Cancel
              </Button>
            </Footer>
          </Modal>
        )}
      </div>
    );
  }
}

ListFile.propTypes = propTypes;
ListFile.defaultProps = defaultProps;

export default ListFile;
