import React, { Component } from 'react';
import PropTypes from 'prop-types';
import omit from 'lodash/omit';
import FileInput, { ListFiles, changeValue, getFileInputProps } from '../FileInput';
import Cropper from '../Cropper';
import Modal, { Body } from '../Modal';

const propTypes = {
  placeHolder: PropTypes.string,
  autoUpload: PropTypes.bool,
  children: PropTypes.func,
  sizes: PropTypes.array
};

const defaultProps = {
  placeHolder: 'You can drop your file(s) here',
  autoUpload: false,
  children: undefined,
  sizes: undefined
};

class ImageInput extends Component {
  state = {
    cropperImage: undefined
  };

  getInputProps = customProps => getFileInputProps(customProps || this.props);
  changeValue = value => changeValue({ value, props: this.props });

  handleDrop = ([value, ...values], handleSubmitFiles) => {
    const { autoUpload } = this.props;
    this.handleEdit(value, 0);
    this.changeValue(
      [value, ...values].map(fileObject => ({
        ...fileObject,
        originalFile: fileObject.file,
        originalType: fileObject.type,
        status: 'waiting'
      }))
    );
    if (values.length && autoUpload) setTimeout(() => handleSubmitFiles(values), 0);
  };

  handleEdit = (file, row) => {
    this.setState({
      cropperImage: {
        originalFile: file.originalFile || file.file,
        originalType: file.originalType || file.type,
        ...file
      },
      cropperImageRow: row
    });
  };

  handlerCrop = handleSubmitFiles => cropperData => {
    const { cropperImageRow } = this.state;
    const { autoUpload } = this.props;
    const { value: [...value] } = this.getInputProps();
    value[cropperImageRow] = { ...cropperData, status: 'waiting' };
    this.changeValue(value);
    if (autoUpload) setTimeout(() => handleSubmitFiles(value), 0);
    this.setState({
      cropperImage: undefined
    });
  };

  handlerCancelCrop = handleSubmitFiles => () => {
    const { cropperImageRow } = this.state;
    const { value: [...value] } = this.getInputProps();
    const { autoUpload } = this.props;
    const fileObject = value[cropperImageRow];
    if (fileObject.file) {
      value[cropperImageRow] = {
        ...fileObject,
        originalFile: fileObject.file,
        originalType: fileObject.type,
        status: 'waiting'
      };
    }
    this.changeValue(value);
    if (autoUpload && fileObject.file) setTimeout(() => handleSubmitFiles(value), 0);
    this.setState({
      cropperImage: undefined
    });
  };

  render() {
    const { placeHolder, sizes, children, ...rest } = this.props;
    const { cropperImage } = this.state;
    return (
      <FileInput
        placeHolder={placeHolder}
        onDrop={this.handleDrop}
        {...omit(rest, ['autoUpload'])}
      >
        {props => {
          const { value, handleDelete, handleSubmitFiles } = props;
          return value && !!value.length && (
            <ListFiles
              value={value}
              handleDelete={handleDelete}
              handleEdit={this.handleEdit}
              customModalEdit
            >
              {cropperImage
              && <Modal isOpen size="lg">
                <Body>
                  <Cropper
                    value={cropperImage}
                    meta={cropperImage.meta}
                    onCrop={this.handlerCrop(handleSubmitFiles)}
                    onCancelCrop={this.handlerCancelCrop(handleSubmitFiles)}
                    sizes={sizes}
                  />
                </Body>
              </Modal>
              }
              {children && children(props)}
            </ListFiles>
          );
        }}
      </FileInput>
    );
  }
}

ImageInput.propTypes = propTypes;
ImageInput.defaultProps = defaultProps;

export default ImageInput;
