import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';

import './main-content-wrapper.scss';

class MainContentWrapper extends PureComponent {
  static propTypes = {
    /** @ignore */
    className: PropTypes.string
  };

  static defaultProps = {
    className: undefined
  };

  static contextTypes = {
    layout: PropTypes.object
  };

  componentWillMount = () => {
    if (this.context.layout) {
      this.context.layout.register('main-content', {});
    }
  };

  render() {
    const { layout: { config: { header, sideColumn } } } = this.context;
    const { className, ...props } = this.props;

    const style = [];
    if (header && header.fixed) style.push('with-header');
    if (sideColumn && !sideColumn.onlyCollapsible && sideColumn.side) {
      style.push(`margin-${sideColumn.side}`);
      if (sideColumn.size) {
        style.push(`margin-${sideColumn.side}-${sideColumn.size}`);
      }
      if (sideColumn.collapsible) {
        sideColumn.collapsible.forEach(element => {
          style.push(`nomargin-${element}`);
        });
      } else {
        style.push('breakpoint-mobile');
      }
    }
    if (style.length === 0) style.push('base');

    return <main className={className} styleName={style.join(' ')} {...props} />;
  }
}

export default MainContentWrapper;
