import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import Bar from './Bar';
import NavButton from './NavButton';
import NavDropdown from './NavDropdown';
import NavItemWrapper from './NavItemWrapper';
import NavItemSeparation from './NavItemSeparation';

import './nav-bar.scss';

const propTypes = {
  /** @ignore */
  className: PropTypes.string,
  /**
   * Make it width full size
   */
  level: PropTypes.oneOf([1, 2]),
  size: PropTypes.oneOf([null, 'xl', 'lg', 'md', 'sm', 'xs']),
  /** sizes where navbar is expected to be hidden (ex: "lg xl") */
  hidden: PropTypes.string
};
const defaultProps = {
  className: undefined,
  level: 1,
  size: 'lg',
  hidden: null
};

const NavBar = ({ className, level, size, hidden, ...props }) => {
  const hiddenSizes = hidden ? hidden.split(' ').map(screensize => `hidden-${screensize}`) : hidden;

  return (
    <div
      className={className}
      styleName={`${classNames('base', hiddenSizes, {
        [`level-wrapper-${level}`]: level,
        [size]: size
      })}`}
      {...props}
    />
  );
};

NavBar.propTypes = propTypes;
NavBar.defaultProps = defaultProps;
NavBar.Bar = Bar;
NavBar.NavButton = NavButton;
NavBar.NavDropdown = NavDropdown;
NavBar.NavItemWrapper = NavItemWrapper;
NavBar.NavItemSeparation = NavItemSeparation;

export default NavBar;
