/* eslint-disable jsx-a11y/label-has-for, jsx-a11y/no-static-element-interactions */
import React from 'react';
import PropTypes from 'prop-types';
import omit from 'lodash/omit';

import FieldControl from '../FieldControl';
import './radio.scss';

function getInputProps(props) {
  const { input, ...resultProps } = props;
  return { ...resultProps, ...input };
}

class Radio extends React.Component {
  static propTypes = {
    disabled: PropTypes.bool,
    options: PropTypes.oneOfType([PropTypes.object, PropTypes.array]),
    value: PropTypes.oneOfType([
      PropTypes.string,
      PropTypes.number,
      PropTypes.bool,
      PropTypes.array,
      PropTypes.object
    ]),
    onChange: PropTypes.func,
    input: PropTypes.object
  };

  static defaultProps = {
    disabled: false,
    options: [],
    value: null,
    onChange: null,
    input: null
  };

  handleOnChange = value => () => {
    const { onChange } = this.props.input || this.props;
    if (typeof onChange === 'function') {
      onChange(value);
    }
  };

  handleOnBlur = value => () => {
    const { onBlur } = this.props.input || this.props;
    if (typeof onBlur === 'function') {
      onBlur(value);
    }
  };

  handleOnClick = ref => () => {
    this[ref].focus();
  }

  render() {
    const {
      options,
      ...props
    } = this.props;

    const parsedOptions = Array.isArray(options) ? options
      : Object.keys(options).map(key => ({ label: key, value: options[key] }));

    return (
      <FieldControl {...props}>
        {restProps => {
          const {
            value,
            disabled,
            ...resultProps
          } = getInputProps(restProps);
          return parsedOptions.map(({ value: optionValue, label: optionLabel, disabled: optionDisabled }) =>
            <div styleName="radio" key={optionValue}>
              <label onClick={this.handleOnClick(optionValue)}>
                <input
                  ref={input => { this[optionValue] = input; }}
                  type="radio"
                  value={optionValue}
                  checked={JSON.stringify(value) === JSON.stringify(optionValue)}
                  onChange={this.handleOnChange(optionValue)}
                  onBlur={this.handleOnBlur(optionValue)}
                  disabled={disabled || optionDisabled}
                  {...omit(resultProps, ['onChange', 'onBlur', 'checked'])}
                />
                {optionLabel}
              </label>
            </div>
          );
        }}
      </FieldControl>
    );
  }
}

export default Radio;
