import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';

import './app-title.scss';

const propTypes = {
  /** @ignore */
  className: PropTypes.string,
  children: PropTypes.node,
  /** sizes where button is expected to be hidden (ex: "lg xl") */
  hidden: PropTypes.string,
  size: PropTypes.oneOf(['sm', 'md', 'lg']),
  variant: PropTypes.oneOf(['', 'dark']),
  /** destination of link */
  linkTo: PropTypes.string
};

const defaultProps = {
  className: undefined,
  children: [],
  hidden: null,
  size: 'md',
  variant: '',
  linkTo: '/'
};

/**
 * An Item to fit inside the SideMenu (or SubMenu)
 */
const AppTitle = props => {
  const { className, children, hidden, size, variant, linkTo, ...rest } = props;
  const hiddenSizes = hidden ? hidden.split(' ').map(screensize => `hidden-${screensize}`) : hidden;

  return (
    <a href={linkTo} className={className} styleName={classNames('base', size, variant, hiddenSizes)} {...rest}>
      {children}
    </a>
  );
};

AppTitle.propTypes = propTypes;
AppTitle.defaultProps = defaultProps;
AppTitle.componentName = 'AppTitle';

export default AppTitle;
