import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';

import './burger-button.scss';

const propTypes = {
  /** @ignore */
  className: PropTypes.string,
  /** @ignore */
  onClick: PropTypes.func,
  /** @ignore */
  disabled: PropTypes.bool,
  /** menu is open */
  open: PropTypes.bool,
  /** sizes where button is expected to be hidden (ex: "lg xl") */
  hidden: PropTypes.string,
  variant: PropTypes.oneOf(['light', 'dark']),
  side: PropTypes.oneOf(['left', 'right'])
};

const defaultProps = {
  className: undefined,
  onClick: null,
  disabled: false,
  open: false,
  hidden: null,
  variant: 'light',
  side: 'left'
};

/**
 * An Item to fit inside the SideMenu (or SubMenu)
 */
const BurgerButton = props => {
  const { className, onClick, disabled, open, hidden, variant, side, ...rest } = props;
  const hiddenSizes = hidden ? hidden.split(' ').map(screensize => `hidden-${screensize}`) : hidden;

  const onDisabledLink = e => {
    if (disabled) {
      e.preventDefault();
    } else if (onClick) {
      onClick(e);
    }
  };

  return (
    <button
      className={className}
      styleName={classNames('base', variant, side, hiddenSizes, {
        'state-open': open
      })}
      onClick={onDisabledLink}
      disabled={disabled}
      {...rest}
    >
      <span styleName={classNames('middle')} />
    </button>
  );
};

BurgerButton.propTypes = propTypes;
BurgerButton.defaultProps = defaultProps;
BurgerButton.componentName = 'BurgerButton';

export default BurgerButton;
