import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';

import item from './side-menu-item.scss'; // eslint-disable-line no-unused-vars
import subMenu from '../SubMenu/sub-menu.scss'; // eslint-disable-line no-unused-vars
import sideMenu from '../side-menu.scss'; // eslint-disable-line no-unused-vars

const propTypes = {
  /** @ignore */
  children: PropTypes.node,
  /** @ignore */
  className: PropTypes.string,
  /** @ignore */
  closeMenu: PropTypes.func,
  /** A component: button, a, react router Link, etc... */
  componentWrapper: PropTypes.oneOfType([PropTypes.string, PropTypes.object, PropTypes.func]),
  /** A component: button, a, react router Link, etc... */
  component: PropTypes.oneOfType([PropTypes.string, PropTypes.object, PropTypes.func]),
  /** A function called on click */
  onClick: PropTypes.func,
  /** Disabled bool */
  disabled: PropTypes.bool,
  /** A boolean that prevents the menu from closing after a click on the item */
  preventsMenuClose: PropTypes.bool,
  /** A separation above and/or below the item */
  separation: PropTypes.oneOf(['top', 'bottom', 'both']),
  active: PropTypes.bool,
  bottom: PropTypes.bool,
  /** true => submenu is hidden when menu not collapsible */
  onlyCollapsible: PropTypes.bool
};

const defaultProps = {
  children: undefined,
  className: undefined,
  onClick: null,
  closeMenu: undefined,
  disabled: false,
  componentWrapper: 'li',
  component: 'span',
  preventsMenuClose: false,
  separation: null,
  active: false,
  bottom: false,
  onlyCollapsible: false
};

/**
 * An Item to fit inside the SideMenu (or SubMenu)
 */
class Item extends PureComponent {
  onClick = e => {
    const { onClick, closeMenu, preventsMenuClose, disabled } = this.props;

    if (disabled) {
      e.preventDefault();
    } else if (onClick) {
      onClick(e);
    }

    if (!preventsMenuClose && !disabled && closeMenu) {
      closeMenu();
    }
  };

  render() {
    const {
      children,
      className,
      disabled,
      componentWrapper: ComponentWrapper,
      component: Component,
      separation,
      active,
      bottom,
      onlyCollapsible,
      closeMenu,
      preventsMenuClose,
      ...rest
    } = this.props;

    return (
      <ComponentWrapper
        className={className}
        styleName={classNames('item.base', {
          'item.position-bottom': bottom,
          'item.active': active,
          [`item.separation-${separation}`]: separation,
          'sideMenu.item-only-collapsible': onlyCollapsible
        })}
      >
        <Component styleName="item.trigger subMenu.item" {...rest} onClick={this.onClick} {...{ disabled }}>
          {children}
        </Component>
      </ComponentWrapper>
    );
  }
}

Item.propTypes = propTypes;
Item.defaultProps = defaultProps;
Item.componentName = 'Item';

export default Item;
