import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import Item from '../Item/index';

import subMenu from './sub-menu.scss'; // eslint-disable-line no-unused-vars
import sideMenu from '../side-menu.scss'; // eslint-disable-line no-unused-vars

const propTypes = {
  /** @ignore */
  children: PropTypes.node,
  /** @ignore */
  className: PropTypes.string,
  /** @ignore */
  closeMenu: PropTypes.func,
  /** An Item */
  title: PropTypes.node.isRequired,
  separation: PropTypes.oneOf(['top', 'bottom', 'both']),
  bottom: PropTypes.bool,
  /** A component: ul, div etc... */
  component: PropTypes.oneOfType([PropTypes.string, PropTypes.object, PropTypes.func]),
  /** true => item is hidden when menu not collapsible */
  onlyCollapsible: PropTypes.bool
};

const defaultProps = {
  children: undefined,
  className: undefined,
  closeMenu: undefined,
  separation: null,
  bottom: false,
  component: 'ul',
  onlyCollapsible: false
};

/**
 * a Sub Menu that fits inside the SideMenu
 */
const SubMenu = props => {
  const {
    children,
    className,
    title,
    separation,
    bottom,
    component: Component,
    onlyCollapsible,
    closeMenu,
    ...rest
  } = props;
  return (
    <div
      className={className}
      styleName={classNames('subMenu.base', {
        'subMenu.position-bottom': bottom,
        [`subMenu.separation-${separation}`]: separation,
        'sideMenu.submenu-only-collapsible': onlyCollapsible
      })}
      {...rest}
    >
      {React.Children.map(title, child => {
        const isValidElement = React.isValidElement(child);
        if (isValidElement) {
          return React.cloneElement(child, { closeMenu });
        }
        return child;
      })}
      <Component styleName="subMenu.list">
        {React.Children.map(children, child => {
          const isValidElement = React.isValidElement(child);
          if (isValidElement && (child.type === Item || child.type === SubMenu)) {
            return React.cloneElement(child, { closeMenu });
          }
          return child;
        })}
      </Component>
    </div>
  );
};

SubMenu.propTypes = propTypes;
SubMenu.defaultProps = defaultProps;
SubMenu.componentName = 'SubMenu';

export default SubMenu;
