import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import RcTooltip from 'rc-tooltip';

import 'rc-tooltip/assets/bootstrap.css';

class Tooltip extends PureComponent {
  static propTypes = {
    trigger: PropTypes.arrayOf(PropTypes.string),
    placement: PropTypes.string,
    children: PropTypes.node,
    overlay: PropTypes.oneOfType([
      PropTypes.node,
      PropTypes.string
    ]),
    component: PropTypes.oneOfType([
      PropTypes.string,
      PropTypes.object,
      PropTypes.func
    ]),
    mouseEnterDelay: PropTypes.number,
    mouseLeaveDelay: PropTypes.number,
    className: PropTypes.string,
    overlayClassName: PropTypes.string
  };

  static defaultProps = {
    trigger: ['hover'],
    component: 'span',
    placement: 'top',
    overlay: null,
    children: null,
    mouseEnterDelay: 0.15,
    mouseLeaveDelay: 0.15,
    className: undefined,
    overlayClassName: undefined
  };

  render() {
    const {
      trigger,
      placement,
      overlay,
      children,
      mouseEnterDelay,
      mouseLeaveDelay,
      component: Component,
      className,
      overlayClassName,
      ...rest
    } = this.props;

    return (
      <RcTooltip
        trigger={trigger}
        mouseEnterDelay={mouseEnterDelay}
        placement={placement}
        mouseLeaveDelay={mouseLeaveDelay}
        overlay={overlay}
        overlayClassName={overlayClassName}
        {...rest}
      >
        <Component className={className} {...rest} >{children}</Component>
      </RcTooltip>
    );
  }
}


export default Tooltip;
